function [data, auxData, metaData, txtData, weights] = mydata_Sula_leucogaster

%% set metaData
metaData.phylum     = 'Chordata'; 
metaData.class      = 'Aves'; 
metaData.order      = 'Suliformes'; 
metaData.family     = 'Sulidae';
metaData.species    = 'Sula_leucogaster'; 
metaData.species_en = 'Brown booby'; 
metaData.ecoCode.climate = {'MA'};
metaData.ecoCode.ecozone = {'MC'};
metaData.ecoCode.habitat = {'0iMc'};
metaData.ecoCode.embryo  = {'Tnsfm'};
metaData.ecoCode.migrate = {};
metaData.ecoCode.food    = {'biCvf'};
metaData.ecoCode.gender  = {'Dg'};
metaData.ecoCode.reprod  = {'O'};
metaData.T_typical  = C2K(42); % K, body temp
metaData.data_0     = {'ab'; 'ax'; 'aR'; 'am'; 'Wwb'; 'Wwi'; 'Ri'}; 
metaData.data_1     = {'t-Ww'}; 

metaData.COMPLETE = 2.5; % using criteria of LikaKear2011

metaData.author   = {'Bas Kooijman'};    
metaData.date_subm = [2018 10 02];              
metaData.email    = {'bas.kooijman@vu.nl'};            
metaData.address  = {'VU University Amsterdam'};   

metaData.curator     = {'Starrlight Augustine'};
metaData.email_cur   = {'starrlight@akvaplan.niva.no'}; 
metaData.date_acc    = [2018 10 02]; 

%% set data
% zero-variate data

data.ab = 41;  units.ab = 'd';    label.ab = 'age at birth';             bibkey.ab = 'AnAge';   
  temp.ab = C2K(39);  units.temp.ab = 'K'; label.temp.ab = 'temperature';
  comment.ab = 'Body temp from ShalWhit1973 as target, but varies considerably';
data.tx = 107; units.tx = 'd';    label.tx = 'time since birth at fledging'; bibkey.tx = 'Dorw1962';   
  temp.tx = C2K(39);  units.temp.tx = 'K'; label.temp.tx = 'temperature';
  comment.tx = 'Data for S. sula, 91 till > 139 d';
data.tR = 1278;   units.tR = 'd';    label.tR = 'time since birth at 1st brood';  bibkey.tR = 'AnAge';
  temp.tR = C2K(39); units.temp.tR = 'K'; label.temp.tR = 'temperature';
  comment.tR = 'Data for S. sula, 2-3 yr';
data.am = 27.2*365;   units.am = 'd';    label.am = 'life span';           bibkey.am = 'AnAge';   
  temp.am = C2K(39);  units.temp.am = 'K'; label.temp.am = 'temperature'; 

data.Wwb = 60; units.Wwb = 'g';   label.Wwb = 'wet weight at birth';     bibkey.Wwb = 'Dorw1962';
data.Wwi = 1750; units.Wwi = 'g';  label.Wwi = 'ultimate wet weight';     bibkey.Wwi = 'Dorw1962';

data.Ri  = 2/365;  units.Ri  = '#/d'; label.Ri  = 'maximum reprod rate';  bibkey.Ri  = 'AnAge';   
  temp.Ri = C2K(39);  units.temp.Ri = 'K'; label.temp.Ri = 'temperature';
  comment.Ri = 'AnAge: 1 clutch/yr';

% uni-variate data      
% t-W data
data.tW = [ ... % time since birth (d), wet weight (g)
  0   60
  6   82
 11  138
 14  205
 18  300
 29  595
 33  674
 43 1028
 54 1175
 60 1350
 70 1400
 94 1290
100 1225
107 1140];
units.tW   = {'d', 'g'};  label.tW = {'time since birth', 'wet weight'};  
temp.tW    = C2K(39);  units.temp.tW = 'K'; label.temp.tW = 'temperature';
bibkey.tW  = 'Dorw1962';
comment.tW = 'Data from Ascension Island';
  
%% set weights for all real data
weights = setweights(data, []);
weights.tW = 10 * weights.tW;
weights.Wwi = 5 * weights.Wwi;

%% set pseudodata and respective weights
[data, units, label, weights] = addpseudodata(data, units, label, weights);

%% pack auxData and txtData for output
auxData.temp = temp;
txtData.units = units;
txtData.label = label;
txtData.bibkey = bibkey;
txtData.comment = comment;

%% Discussion points
D1 = 'Feeding is reduced towards end of nestling period';
D2 = 'Body temerature is guessed';
D3 = 'Long tp cannot be captured by std model';
metaData.discussion = struct('D1', D1, 'D2', D2, 'D3', D3);

%% Links
metaData.links.id_CoL = '53FBG'; % Cat of Life
metaData.links.id_ITIS = '174704'; % ITIS
metaData.links.id_EoL = '45509072'; % Ency of Life
metaData.links.id_Wiki = 'Sula_leucogaster'; % Wikipedia
metaData.links.id_ADW = 'Sula_leucogaster'; % ADW
metaData.links.id_Taxo = '51662'; % Taxonomicon
metaData.links.id_WoRMS = '212597'; % WoRMS
metaData.links.id_avibase = '5EC21767FC58DB7D'; % avibase
metaData.links.id_birdlife = 'brown-booby-sula-leucogaster'; % birdlife
metaData.links.id_AnAge = 'Sula_leucogaster'; % AnAge


%% References
bibkey = 'Wiki'; type = 'Misc'; bib = ...
'howpublished = {\url{http://en.wikipedia.org/wiki/Sula_leucogaster}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Kooy2010'; type = 'Book'; bib = [ ...  % used in setting of chemical parameters and pseudodata
'author = {Kooijman, S.A.L.M.}, ' ...
'year = {2010}, ' ...
'title  = {Dynamic Energy Budget theory for metabolic organisation}, ' ...
'publisher = {Cambridge Univ. Press, Cambridge}, ' ...
'pages = {Table 4.2 (page 150), 8.1 (page 300)}, ' ...
'howpublished = {\url{../../../bib/Kooy2010.html}}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'Dorw1962'; type = 'Article'; bib = [ ... 
'author = {D. F. Dorwad}, ' ... 
'doi = {10.1111/j.1474-919X.1962.tb07244.x}, ' ...
'year = {1962}, ' ...
'title = {COMPARATIVE BIOLOGY OF THE WHITE BOOBY AND THE BROWN BOOBY \emph{Sula} SPP. AT {A}SCENSION}, ' ...
'journal = {Ibis}, ' ...
'volume = {103B}, ' ...
'pages = {174--220}'];
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];
%
bibkey = 'AnAge'; type = 'Misc'; bib = ...
'howpublished = {\url{http://genomics.senescence.info/species/entry.php?species=Sula_leucogaster}}';
metaData.biblist.(bibkey) = ['''@', type, '{', bibkey, ', ' bib, '}'';'];

